@@ -4,7 +4,7 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: game.c,v 1.32 2002/04/29 03:40:50 oohara Exp $ */
+/* $Id: game.c,v 1.34 2009/11/08 06:21:24 oohara Exp $ */
 
 /* DEBUG and JSTK are defined in config.h */
 #include <config.h>
@@ -404,22 +404,22 @@ static void DrawInfo(void)
 static void do_actions(void)
 {
   int obj;
-  int ocheck;
   DelAtt DelFlag;
 
-  for (obj=manage->PlayerMax-1,ocheck=0; (obj>=0 && ocheck<manage->PlayerNum); obj--)
+  for (obj=manage->PlayerMax-1; obj>=0; obj--)
+    manage->player[obj]->Data.shouldAct = manage->player[obj]->Data.used;
+  for (obj=manage->PlayerMax-1; obj>=0; obj--)
   {
-    if (manage->player[obj]->Data.used == True)
+    if (manage->player[obj]->Data.shouldAct == True)
     {
       if (manage->player[obj]->Action(&(manage->player[obj]->Data)) == NullDel)
         DelObj(manage->player[obj]);
-      else
-        /* action is done and the object is still alive */
-        ocheck++;
     }
   }
   
-  for (obj=0,ocheck=0; (obj<manage->EnemyMax && ocheck<manage->EnemyNum); obj++)
+  for (obj=0; obj<manage->EnemyMax; obj++)
+    manage->enemy[obj]->Data.shouldAct = manage->enemy[obj]->Data.used;
+  for (obj=0; obj<manage->EnemyMax; obj++)
   {
     if (manage->enemy[obj]->Data.used == True)
     {
@@ -427,7 +427,7 @@ static void do_actions(void)
       switch (DelFlag)
       {
       case NoneDel:
-        ocheck++;
+        /* do nothing */
         break;
       case BossDel:
 #ifdef DEBUG
@@ -436,11 +436,14 @@ static void do_actions(void)
         if ((DelFlag == BossDel) && (manage->BossTime <= 0))
           player->Rec[0].score -= manage->enemy[obj]->Data.Point;
         manage->BossKill = True;
+        /* fall off */
       case ZakoDel:
         player->Rec[0].score += manage->enemy[obj]->Data.Point;
         manage->StageShotDown++;
+        /* fall off */
       case NullDel:
         DelObj(manage->enemy[obj]);
+        break;
       }
     }
   }
