@@ -4,7 +4,7 @@
  *
  * This is a copyleft program.  See the file LICENSE for details.
  */
-/* $Id: version.h,v 1.6 2002/05/26 08:37:38 oohara Exp $ */
+/* $Id: version.h,v 1.7 2009/11/08 06:18:27 oohara Exp $ */
 
 #include <config.h>
 #if !defined _VERSION_H_
@@ -12,6 +12,6 @@
 
 /* VERSION is defined in config.h because we use automake */
 
-#define UPDATE "26 May 2002"
+#define UPDATE "08 Nov 2009"
 
 #endif
